#
# spec file for package libunibreak
#
# Copyright (c) 2024 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%define         libversion 5
%define         altver  5_1
Name:           libunibreak
Version:        5.1
Release:        2.3
Summary:        Unicode line-breaking library
License:        Zlib
Group:          Development/Libraries/C and C++
URL:            https://github.com/adah1972/libunibreak
Source0:        https://github.com/adah1972/libunibreak/releases/download/libunibreak_%{altver}/%{name}-%{version}.tar.gz
Source1:        baselibs.conf
# PATCH-FIX-UPSTREAM libunibreak-include-test-data.patch gh#adah1972/libunibreak#41 badshah400@gmail.com -- Include working unicode data for tests, as tests fail against upstream unicode 15 data files; upstream commits b992362 and 839f06f
Patch0:         libunibreak-include-test-data.patch
# Needed because Patch0 modifies Makefile.am files
BuildRequires:  libtool
# /
BuildRequires:  pkgconfig
Obsoletes:      liblinebreak < 2.1
Provides:       liblinebreak = 2.1

%description
Libunibreak is the successor of liblinebreak, an implementation of the line
breaking algorithm as described in Unicode 6.0.0 Standard Annex 14, Revision
26, available at http://www.unicode.org/reports/tr14/tr14-26.html

It is designed to be used in a generic text renderer. FBReader is one
real-world example, and you may also check some simple sample code, like
showbreak and breaktext.

%package devel
Summary:        Development files for libunibreak
Group:          Development/Libraries/C and C++
Requires:       %{name}%{libversion} = %{version}
Requires:       pkgconfig
Obsoletes:      liblinebreak-devel < 2.1
Provides:       liblinebreak-devel = 2.1

%description devel
The libunibreak-devel package contains libraries and header files for
developing applications that use libunibreak.

%package -n libunibreak%{libversion}
Summary:        Unicode line-breaking library
Group:          Development/Libraries/C and C++

%description -n libunibreak%{libversion}
Libunibreak is an implementation of the line breaking and word breaking
algorithm as described in Unicode Standard Annex 14 and Unicode Standard
Annex 29.

%prep
%autosetup -p1

%build
# Patch0 modifies Makefile.am
autoreconf -fvi
# /
%configure \
	--disable-static
%make_build

%install
%make_install
find %{buildroot} -name '*.*a' -print -delete

%check
%make_build check

%post -n libunibreak%{libversion} -p /sbin/ldconfig
%postun -n libunibreak%{libversion} -p /sbin/ldconfig

%files -n libunibreak%{libversion}
%license LICENCE
%{_libdir}/*.so.%{libversion}{,.*}

%files devel
%license LICENCE
%doc AUTHORS NEWS README.md
%{_includedir}/*
%{_libdir}/*.so
%{_libdir}/pkgconfig/libunibreak.pc

%changelog
* Wed Aug  7 2024 llyyr <llyyr.public@gmail.com>
- Add baselibs.conf: 32-bit biarch builds of libass needs it.
* Tue Jan  2 2024 Atri Bhattacharya <badshah400@gmail.com>
- Update to version 5.1:
  * Speed up line-break property lookup.
  * Update the data to conform to Unicode 15.
- Drop LineBreakTest.txt, WordBreakTest.txt, and
  GraphemeBreakTest.txt from upstream; these break tests.
- Add libunibreak-include-test-data.patch: Add data for tests that
  work with current code, tests fail with upstream Unicode 15
  datafiles (gh#adah1972/libunibreak#41); patch taken from
  upstream commits. Add BuildRequires: libtool as patch modifies
  build files.
* Tue Jan  2 2024 Atri Bhattacharya <badshah400@gmail.com>
- Resolve specfile conflicts with Factory.
* Sat Nov 27 2021 Andreas Stieger <andreas.stieger@gmx.de>
- update to 5.0:
  * Update the data to conform to Unicode 14
  * Add per_code_point variants of utf8 and utf16 functions
  * Do not always break after the last character
* Mon May 17 2021 Andreas Stieger <andreas.stieger@gmx.de>
- update to 4.3:
  * conform to Unicode 13
  * Change the handling of ellipses as per UAX# 14-45
  * Fix the handling of leading spaces
* Mon Mar 18 2019 lars@linux-schulserver.de - 4.1
- Update to version 4.1:
  * Update the code and data to conform to Unicode 11.0.0, especially
    adding support for extended pictographs in word and grapheme breaking
  * ZWJ support has been much improved (it was broken)
  * Make minor tweaks to the project files
- run tests - added:
  + LineBreakTest.txt,
  + WordBreakTest.txt and
  + GraphemeBreakTest.txt
  from http://www.unicode.org/Public/UNIDATA/auxiliary/ to run the
  tests offline
- spec file cleanup:
  + put documentation into devel package
  + use %%%%license macro, if possible
* Wed Feb 14 2018 aloisio@gmx.com
- Update to version 4.0
  * Update the code and data to conform to Unicode 9.0.0
  * Add grapheme breaking support
  * Tested and enhanced according to the Unicode test suite
  * Make bug fixes
* Thu Jun 25 2015 sleep_walker@suse.cz
- bump to 3.0
- removed libunibreak-1.1-destdir.patch as not needed
  - patch was fixing symlink for static library and we're running
    configure with --disable-static and failure is silently ignored so
    dropping patch is safe and has no effect in result
* Fri May 23 2014 trcs@gmx.com
- Add the function documentation comments to the header files
- Adjust code structure
- Applied spec-cleaner to the spec file
- Declare get_next_char_utf* will be changed to lb_get_next_char_utf*
- Define is_line_breakable to alias to is_breakable linebreakdef.h
- Make a few bug fixes
- Make get_lb_prop_lang static and not an exported symbol
- Move the declarations of get_next_char_utf* from linebreak.h to
- Update build files to support libtool 2.4
- Update the code and data to conform to Unicode 6.2.0
* Thu Aug  1 2013 lars@linux-schulserver.de
- initial version 1.0
